Improve this Doc View Source

Used to configure the options passed to the `$http` service when making a template request.

For example, it can be used for specifying the "Accept" header that is sent to the server, when requesting a template.

## Methods

- ###

  `httpOptions([value]);`

  The options to be passed to the `$http` service when making the request. You can use this to override options such as the "Accept" header for template requests.

  The `$templateRequest` will set the `cache` and the `transformResponse` properties of the options if not overridden here.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  value (optional) | string | new value for the `$http` options.

  #### Returns

  stringself | Returns the `$http` options when used as getter and self if used as setter.